@@ -18,8 +18,6 @@
 Command-line interface to the Tacker APIs
 """
 
-from __future__ import print_function
-
 import argparse
 import getpass
 import inspect
@@ -104,6 +102,7 @@ class BashCompletionCommand(openstack_command.OpenStackCommand):
     """Prints all of the commands and options for bash-completion."""
     resource = "bash_completion"
 
+
 COMMAND_V1 = {
     'bash-completion': BashCompletionCommand,
     'ext-list': extension.ListExt,
@@ -639,8 +638,8 @@ class TackerShell(app.App):
                                      self.options.os_project_domain_id)) or
                                 self.options.os_project_id)
 
-                if (not self.options.os_username
-                        and not self.options.os_user_id):
+                if (not self.options.os_username and
+                        not self.options.os_user_id):
                     raise exc.CommandError(
                         _("You must provide a username or user ID via"
                           "  --os-username, env[OS_USERNAME] or"
