@@ -14,8 +14,6 @@
 #    under the License.
 #
 
-from __future__ import print_function
-
 import abc
 import argparse
 import logging
@@ -164,9 +162,9 @@ def _process_previous_argument(current_arg, _value_number, current_type_str,
                                values_specs):
     if current_arg is not None:
         if _value_number == 0 and (current_type_str or _list_flag):
-                # This kind of argument should have value
-                raise exceptions.CommandError(
-                    _("Invalid values_specs %s") % ' '.join(values_specs))
+            # This kind of argument should have value
+            raise exceptions.CommandError(
+                message=_("Invalid values_specs %s") % ' '.join(values_specs))
         if _value_number > 1 or _list_flag or current_type_str == 'list':
             current_arg.update({'nargs': '+'})
         elif _value_number == 0:
@@ -237,7 +235,8 @@ def parse_args_to_dict(values_specs):
                 _value_number = 0
             if _item in _options:
                 raise exceptions.CommandError(
-                    _("Duplicated options %s") % ' '.join(values_specs))
+                    message=_("Duplicated "
+                              "options %s") % ' '.join(values_specs))
             else:
                 _options.update({_item: {}})
             current_arg = _options[_item]
@@ -245,7 +244,8 @@ def parse_args_to_dict(values_specs):
         elif _item.startswith('type='):
             if current_arg is None:
                 raise exceptions.CommandError(
-                    _("Invalid values_specs %s") % ' '.join(values_specs))
+                    message=_("Invalid "
+                              "values_specs %s") % ' '.join(values_specs))
             if 'type' not in current_arg:
                 current_type_str = _item.split('=', 2)[1]
                 current_arg.update({'type': eval(current_type_str)})
@@ -267,7 +267,8 @@ def parse_args_to_dict(values_specs):
             if (not current_item or '=' in current_item or
                _item.startswith('-') and not is_number(_item)):
                 raise exceptions.CommandError(
-                    _("Invalid values_specs %s") % ' '.join(values_specs))
+                    message=_("Invalid "
+                              "values_specs %s") % ' '.join(values_specs))
             _value_number += 1
 
         _values_specs.append(_item)
@@ -332,6 +333,7 @@ class TableFormater(table.TableFormatter):
 
     https://bugs.launchpad.net/python-tackerclient/+bug/1165962
     """
+
     def emit_list(self, column_names, data, stdout, parsed_args):
         if column_names:
             super(TableFormater, self).emit_list(column_names, data, stdout,
@@ -483,7 +485,8 @@ class UpdateCommand(TackerCommand):
             body[self.resource] = _extra_values
         if not body[self.resource]:
             raise exceptions.CommandError(
-                _("Must specify new values to update %s") % self.resource)
+                message=_("Must specify new"
+                          " values to update %s") % self.resource)
         if self.allow_names:
             _id = find_resourceid_by_name_or_id(
                 tacker_client, self.resource, parsed_args.id)
@@ -559,12 +562,12 @@ class DeleteCommand(TackerCommand):
                                                  'resource': self.resource})
             err_msg = _("\n\nUnable to delete the below"
                         " %s(s):") % self.resource
-            for failed_id, error in failed_items.iteritems():
+            for failed_id, error in failed_items.items():
                 err_msg += (_('\n Cannot delete %(failed_id)s: %(error)s')
                             % {'failed_id': failed_id,
                                'error': error})
             msg += err_msg
-            raise exceptions.CommandError(msg)
+            raise exceptions.CommandError(message=msg)
         else:
             print((_('All specified %(resource)s(s) %(msg)s successfully')
                    % {'msg': self.deleted_msg.get(self.resource, 'deleted'),
